@@ -26,6 +26,7 @@
 #include <libgnomeui/gnome-rr.h>
 #include <X11/extensions/Xrandr.h>
 #include <X11/extensions/xf86vmode.h>
+#include <gconf/gconf-client.h>
 #include <gdk/gdkx.h>
 
 #include "gcm-device-xrandr.h"
@@ -50,12 +51,10 @@ static void     gcm_device_xrandr_finalize	(GObject     *object);
 struct _GcmDeviceXrandrPrivate
 {
 	gchar				*native_device;
-	gchar				*eisa_id;
-	gchar				*edid_md5;
 	guint				 gamma_size;
 	GcmEdid				*edid;
 	GcmDmi				*dmi;
-	GSettings			*settings;
+	GConfClient			*gconf_client;
 	GcmXserver			*xserver;
 	GcmScreen			*screen;
 	gboolean			 xrandr_fallback;
@@ -66,8 +65,6 @@ enum {
 	PROP_0,
 	PROP_NATIVE_DEVICE,
 	PROP_XRANDR_FALLBACK,
-	PROP_EISA_ID,
-	PROP_EDID_MD5,
 	PROP_LAST
 };
 
@@ -86,25 +83,7 @@ gcm_device_xrandr_get_native_device (GcmDeviceXrandr *device_xrandr)
 }
 
 /**
- * gcm_device_xrandr_get_eisa_id:
- **/
-const gchar *
-gcm_device_xrandr_get_eisa_id (GcmDeviceXrandr *device_xrandr)
-{
-	return device_xrandr->priv->eisa_id;
-}
-
-/**
- * gcm_device_xrandr_get_edid_md5:
- **/
-const gchar *
-gcm_device_xrandr_get_edid_md5 (GcmDeviceXrandr *device_xrandr)
-{
-	return device_xrandr->priv->edid_md5;
-}
-
-/**
- * gcm_device_xrandr_get_fallback:
+ * gcm_device_xrandr_get_native_device:
  **/
 gboolean
 gcm_device_xrandr_get_fallback (GcmDeviceXrandr *device_xrandr)
@@ -212,7 +191,7 @@ gcm_device_xrandr_get_id_for_xrandr_device (GcmDeviceXrandr *device_xrandr, Gnom
 	name = gcm_edid_get_monitor_name (priv->edid);
 	if (name != NULL)
 		g_string_append_printf (string, "_%s", name);
-	ascii = gcm_edid_get_eisa_id (priv->edid);
+	ascii = gcm_edid_get_ascii_string (priv->edid);
 	if (ascii != NULL)
 		g_string_append_printf (string, "_%s", ascii);
 	serial = gcm_edid_get_serial_number (priv->edid);
@@ -271,8 +250,6 @@ gcm_device_xrandr_set_from_output (GcmDevice *device, GnomeRROutput *output, GEr
 	model = gcm_edid_get_monitor_name (priv->edid);
 	manufacturer = gcm_edid_get_vendor_name (priv->edid);
 	serial = gcm_edid_get_serial_number (priv->edid);
-	priv->eisa_id = g_strdup (gcm_edid_get_eisa_id (priv->edid));
-	priv->edid_md5 = g_strdup (gcm_edid_get_checksum (priv->edid));
 
 	/* refine data if it's missing */
 	output_name = gnome_rr_output_get_name (output);
@@ -457,42 +434,6 @@ gcm_device_xrandr_set_remove_atom (GcmDeviceXrandr *device_xrandr, gboolean remo
 	device_xrandr->priv->remove_atom = remove_atom;
 }
 
-/**
- * gcm_device_xrandr_get_config_data:
- **/
-static gchar *
-gcm_device_xrandr_get_config_data (GcmDevice *device)
-{
-	GcmDeviceXrandr *device_xrandr = GCM_DEVICE_XRANDR (device);
-	GcmDeviceXrandrPrivate *priv = device_xrandr->priv;
-	return g_strdup_printf ("edid-hash=%s", priv->edid_md5);
-}
-
-/**
- * gcm_device_xrandr_is_primary:
- *
- * Return value: %TRUE is the monitor is left-most
- **/
-gboolean
-gcm_device_xrandr_is_primary (GcmDeviceXrandr *device_xrandr)
-{
-	gint x, y;
-	gboolean ret = FALSE;
-	GnomeRROutput *output;
-
-	/* check we have an output */
-	output = gcm_screen_get_output_by_name (device_xrandr->priv->screen,
-						device_xrandr->priv->native_device, NULL);
-	if (output == NULL)
-		goto out;
-
-	/* is the monitor our primary monitor */
-	gnome_rr_output_get_position (output, &x, &y);
-	ret = (x == 0 && y == 0);
-out:
-	return ret;
-}
-
 /**
  * gcm_device_xrandr_apply:
  *
@@ -539,22 +480,15 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 		goto out;
 	}
 
-	/* if not saved, try to find default profile */
+	/* if not saved, try to find default filename */
 	saved = gcm_device_get_saved (device);
-	profile = gcm_device_get_default_profile (device);
-	if (profile != NULL)
-		g_object_ref (profile);
-	if (!saved && profile == NULL) {
-		filename_systemwide = g_strdup_printf ("%s/icc/%s.icc", GCM_SYSTEM_PROFILES_DIR, id);
+	filename = gcm_device_get_profile_filename (device);
+	if (!saved && filename == NULL) {
+		filename_systemwide = g_strdup_printf ("%s/%s.icc", GCM_SYSTEM_PROFILES_DIR, id);
 		ret = g_file_test (filename_systemwide, G_FILE_TEST_EXISTS);
 		if (ret) {
 			egg_debug ("using systemwide %s as profile", filename_systemwide);
-			profile = gcm_profile_default_new ();
-			file = g_file_new_for_path (filename_systemwide);
-			ret = gcm_profile_parse (profile, file, error);
-			g_object_unref (file);
-			if (!ret)
-				goto out;
+			filename = g_strdup (filename_systemwide);
 		}
 	}
 
@@ -576,9 +510,19 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 		goto out;
 
 	/* only set the CLUT if we're not seting the atom */
-	use_global = g_settings_get_boolean (priv->settings, GCM_SETTINGS_GLOBAL_DISPLAY_CORRECTION);
-	if (use_global && profile != NULL)
+	use_global = gconf_client_get_bool (priv->gconf_client, GCM_SETTINGS_GLOBAL_DISPLAY_CORRECTION, NULL);
+	if (use_global && filename != NULL) {
+		/* create CLUT */
+		profile = gcm_profile_default_new ();
+		file = g_file_new_for_path (filename);
+		ret = gcm_profile_parse (profile, file, error);
+		g_object_unref (file);
+		if (!ret)
+			goto out;
+
+		/* create a CLUT from the profile */
 		clut = gcm_profile_generate_vcgt (profile, size);
+	}
 
 	/* create dummy CLUT if we failed */
 	if (clut == NULL) {
@@ -610,8 +554,8 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 	leftmost_screen = (x == 0 && y == 0);
 
 	/* either remove the atoms or set them */
-	use_atom = g_settings_get_boolean (priv->settings, GCM_SETTINGS_SET_ICC_PROFILE_ATOM);
-	if (!use_atom || profile == NULL) {
+	use_atom = gconf_client_get_bool (priv->gconf_client, GCM_SETTINGS_SET_ICC_PROFILE_ATOM, NULL);
+	if (!use_atom || filename == NULL) {
 
 		/* at login we don't need to remove any previously set options */
 		if (!priv->remove_atom)
@@ -633,7 +577,6 @@ gcm_device_xrandr_apply (GcmDevice *device, GError **error)
 		}
 	} else {
 		/* set the per-output and per screen profile atoms */
-		filename = gcm_profile_get_filename (profile);
 		ret = gcm_xserver_set_output_profile (priv->xserver, output_name, filename, error);
 		if (!ret)
 			goto out;
@@ -676,12 +619,6 @@ gcm_device_xrandr_get_property (GObject *object, guint prop_id, GValue *value, G
 	case PROP_XRANDR_FALLBACK:
 		g_value_set_boolean (value, priv->xrandr_fallback);
 		break;
-	case PROP_EISA_ID:
-		g_value_set_string (value, priv->eisa_id);
-		break;
-	case PROP_EDID_MD5:
-		g_value_set_string (value, priv->edid_md5);
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -723,7 +660,6 @@ gcm_device_xrandr_class_init (GcmDeviceXrandrClass *klass)
 	object_class->set_property = gcm_device_xrandr_set_property;
 
 	device_class->apply = gcm_device_xrandr_apply;
-	device_class->get_config_data = gcm_device_xrandr_get_config_data;
 
 	/**
 	 * GcmDeviceXrandr:native-device:
@@ -741,22 +677,6 @@ gcm_device_xrandr_class_init (GcmDeviceXrandrClass *klass)
 				      G_PARAM_READABLE);
 	g_object_class_install_property (object_class, PROP_XRANDR_FALLBACK, pspec);
 
-	/**
-	 * GcmDeviceXrandr:eisa-id:
-	 */
-	pspec = g_param_spec_string ("eisa-id", NULL, NULL,
-				     NULL,
-				     G_PARAM_READABLE);
-	g_object_class_install_property (object_class, PROP_EISA_ID, pspec);
-
-	/**
-	 * GcmDeviceXrandr:edid-md5:
-	 */
-	pspec = g_param_spec_string ("edid-md", NULL, NULL,
-				     NULL,
-				     G_PARAM_READABLE);
-	g_object_class_install_property (object_class, PROP_EDID_MD5, pspec);
-
 	g_type_class_add_private (klass, sizeof (GcmDeviceXrandrPrivate));
 }
 
@@ -768,14 +688,12 @@ gcm_device_xrandr_init (GcmDeviceXrandr *device_xrandr)
 {
 	device_xrandr->priv = GCM_DEVICE_XRANDR_GET_PRIVATE (device_xrandr);
 	device_xrandr->priv->native_device = NULL;
-	device_xrandr->priv->eisa_id = NULL;
-	device_xrandr->priv->edid_md5 = NULL;
 	device_xrandr->priv->xrandr_fallback = FALSE;
 	device_xrandr->priv->remove_atom = TRUE;
 	device_xrandr->priv->gamma_size = 0;
 	device_xrandr->priv->edid = gcm_edid_new ();
 	device_xrandr->priv->dmi = gcm_dmi_new ();
-	device_xrandr->priv->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
+	device_xrandr->priv->gconf_client = gconf_client_get_default ();
 	device_xrandr->priv->screen = gcm_screen_new ();
 	device_xrandr->priv->xserver = gcm_xserver_new ();
 }
@@ -790,11 +708,9 @@ gcm_device_xrandr_finalize (GObject *object)
 	GcmDeviceXrandrPrivate *priv = device_xrandr->priv;
 
 	g_free (priv->native_device);
-	g_free (priv->eisa_id);
-	g_free (priv->edid_md5);
 	g_object_unref (priv->edid);
 	g_object_unref (priv->dmi);
-	g_object_unref (priv->settings);
+	g_object_unref (priv->gconf_client);
 	g_object_unref (priv->screen);
 	g_object_unref (priv->xserver);
 
